@@ -200,7 +200,7 @@
 
 (when (> total-memory (* 4 big-size))
   (clear-and-gc)
-  (let ((bigstr (make-string big-size #\space)))
+  (let ((bigstr (make-string big-size)))
     (define (big-string-filler)
       (do ((i 0 (+ i 1)))
 	  ((= i big-size))
@@ -235,13 +235,9 @@
 	(let ((big2 (substring big1 (- (ash 1 31) 10) (+ (ash 1 31) 10))))
 	  (test big2 "dddddddddddddddddddd")
 	  (test (length big2) 20)
-	  (let ((big3 (make-string 20 #\null)))
+	  (let ((big3 (make-string 20)))
 	    (copy bigstr big3 (- (ash 1 31) 10) (+ (ash 1 31) 10))
 	    (test (string=? big2 big3) #t)))))
-    (let ((bstr (string-upcase bigstr)))
-      (test (string-ref bstr 0) #\B)
-      (test (string-ref bstr (- (ash 1 31) 1)) #\D)
-      (test (string-position "DDDD" bstr) (- (ash 1 31) 10)))
     (let ((p (call-with-output-string 
 	      (lambda (p)
 		(write-string bigstr p (- (ash 1 31) 10) (+ (ash 1 31) 10))))))
@@ -252,7 +248,7 @@
       (test (byte-vector? bv) #t)
       (test (length bv) (length bigstr))
       (let ((bvi (byte-vector-ref bv (- (ash 1 31) 100))))
-      (test bvi (char->integer (string-ref (byte-vector->string bigstr) (- (ash 1 31) 100)))))))
+      (test bvi (char->integer (string-ref (byte-vector->string bv) (- (ash 1 31) 100)))))))
   
   (clear-and-gc)
   (let ((size little-size))
@@ -290,7 +286,7 @@
 	(test (string=? str str1) #t))))
   
   (clear-and-gc)
-  (let ((bigstr (make-string (* 2 big-size) #\space)))
+  (let ((bigstr (make-string (* 2 big-size))))
     (test (length bigstr) (* 2 big-size))
     (string-set! bigstr (- big-size 10000000) #\a)
     (test (string-ref bigstr (- big-size 10000000)) #\a)
@@ -340,7 +336,7 @@
 (format () "~%byte-vectors...~%")
 
 (when (> total-memory (* 4 big-size))
-  (let ((bigstr (make-byte-vector big-size 32)))
+  (let ((bigstr (make-byte-vector big-size)))
     (test (length bigstr) big-size)
     (byte-vector-set! bigstr (- big-size 10000000) 65)
     (test (byte-vector-ref bigstr (- big-size 10000000)) 65)
@@ -703,6 +699,7 @@
       (format () "noise: ~A~%" mx))))
 
 (define (float-2d-test skip)
+  (format *stderr* "float-2d ~A~%" skip)
   (let ((fvr (make-float-vector (list skip fft-size) 0.0)))
     (do ((i 0 (+ i 1))
 	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
@@ -725,12 +722,6 @@
   (float-2d-test 2))
 (clear-and-gc)
 
-(when (> total-memory (* 9 (ash 1 33)))
-  (float-2d-test (ash 1 16))) ; fft-size (ash 1 17) -> (* 8 (ash 1 33))
-(let-temporarily ((fft-size 32))
-  (float-2d-test 2))
-(clear-and-gc)
-  
 
 ;; --------------------------------------------------------------------------------
 (format () "~%int-vectors...~%")  
