@@ -13,12 +13,12 @@
 	  ((not pos))
 	(unless (= pos new-pos)
 	  (let* ((start (do ((k new-pos (+ k 1))) ; char-position here is slower!
-			    ((or (= k pos)
-				 (char-alphabetic? (string-ref line k)))
+			    ((or (char-alphabetic? (string-ref line k))
+				 (= k pos))
 			     k)))
 		 (end (do ((k (- pos 1) (- k 1)))
-			  ((or (= k start)
-			       (char-alphabetic? (string-ref line k)))
+			  ((or (char-alphabetic? (string-ref line k))
+			       (= k start))
 			   (+ k 1)))))
 	    (when (> end start)
 	      (let ((word (string->symbol (substring line start end))))
