@@ -51,8 +51,8 @@
 	(if (not (morally-equal? fv-copy fv))
 	    (format *stderr* "float-vector reverse! twice: ~A ~A~%" fv fv-copy))
 	(let ((fv1 (apply float-vector (make-list len 1.0))))
-	  (if (or (not (= (length fv1) len))
-		  (not (= (fv1 (- len 1)) 1.0)))
+	  (if (not (and (= (length fv1) len)
+			(= (fv1 (- len 1)) 1.0)))
 	      (format *stderr* "float-vector apply: ~A ~A~%" len (fv (- len 1)))))
 	))))
 
@@ -135,8 +135,8 @@
 	(if (not (equal? fv-copy fv))
 	    (format *stderr* "vector reverse! twice: ~A ~A~%" fv fv-copy))
 	(let ((fv1 (apply vector (make-list len 1))))
-	  (if (or (not (= (length fv1) len))
-		  (not (= (fv1 (- len 1)) 1)))
+	  (if (not (and (= (length fv1) len)
+			(= (fv1 (- len 1)) 1)))
 	      (format *stderr* "vector apply: ~A ~A~%" len (fv (- len 1)))))
 	))))
 
@@ -179,8 +179,8 @@
 	(if (not (string=? fv-copy fv))
 	    (format *stderr* "string reverse! twice: ~A ~A~%" fv fv-copy))
 	(let ((fv1 (apply string (make-list len #\a))))
-	  (if (or (not (= (length fv1) len))
-		  (not (char=? (fv1 (- len 1)) #\a)))
+	  (if (not (and (= (length fv1) len)
+			(char=? (fv1 (- len 1)) #\a)))
 	      (format *stderr* "string apply: ~A ~A~%" len (fv (- len 1)))))
 	))))
 
@@ -349,7 +349,6 @@
   (let* ((odd-bound (ash (+ n 1) -1))
 	 (prime-list (odd-get n))
 	 (result (make-int-vector odd-bound 0))
-	 (resp 0)
 	 (n2 (/ n 2))) ; this optimization suggested by "Peter" (in comp.lang.lisp)
     (do ((i 0 (+ i 1)))
 	((= i odd-bound))
