@@ -4,7 +4,6 @@
 		     ("teq.scm" . "v-eq")
 		     ("tfft.scm" . "v-fft")
 		     ("tref.scm" . "v-ref")
-		     ("tlet.scm" . "v-let")
 		     ("tauto.scm" . "v-auto")
 		     ("s7test.scm" . "v-test")
 		     ("tcopy.scm" . "v-cop")
@@ -20,6 +19,7 @@
 		     ("tall.scm" . "v-all")
 		     ("snd-test.scm" . "v-call")
 		     ("dup.scm" . "v-dup")
+		     ("tset.scm" . "v-set")
 		     ))
 
 (define (last-callg)
@@ -57,25 +57,25 @@
          ;;              my $space = ' ' x max($CC_col_widths->[$i] - length($count), 0);
 	 (format *stderr* "~NC ~A~D -> ~A~D: ~NC~%" 8 #\space outfile (- next 1) outfile next 8 #\space)
 	 (system (format #f "./snd compare-calls.scm -e '(compare-calls \"~A~D\" \"~A~D\")'" outfile (- next 1) outfile next)))))
-   (list (list "snd -noinit" "tpeak.scm")
+   (list (list "repl" "tpeak.scm")
 	 (list "repl" "tmac.scm")
-	 (list "repl" "dup.scm")
 	 (list "repl" "tref.scm")
 	 (list "snd -noinit" "make-index.scm")
 	 (list "repl" "tauto.scm")
 	 (list "repl" "teq.scm")
 	 (list "repl" "s7test.scm")
 	 (list "repl" "lt.scm")
-	 (list "repl" "tread.scm")
 	 (list "repl" "tcopy.scm")
+	 (list "repl" "tread.scm")
 	 (list "repl" "tform.scm")
-	 (list "repl" "tlet.scm")
 	 (list "repl" "tfft.scm")
 	 (list "repl" "tmap.scm")
 	 (list "repl" "titer.scm")
 	 (list "repl" "tsort.scm")
 	 ;(list "repl" "lg.scm")
 	 (list "repl" "thash.scm")
+	 (list "repl" "tset.scm")
+	 (list "repl" "dup.scm")
 	 (list "snd -noinit" "tgen.scm")    ; repl here + cload sndlib was slower
 	 (list "snd -noinit" "tall.scm")
 	 (list "snd -l" "snd-test.scm")
